import { scaleOrdinal } from 'd3';

const colorScale = scaleOrdinal()
	.domain(['apple','lemon'])
	.range(['#c11d1d','#eae600']);

const radiusScale = scaleOrdinal()
	.domain(['apple','lemon'])
	.range([50,30]);

const xPosition = (d,i) => i * 120 + 60;

// Render the fruitBowl
export const fruitBowl = (selection, props) => {
  // Deconstruct the props argument
  const { fruits, height } = props;
 
  // Create a Data Join ( Data with DOM Elements )
  const circles = selection.selectAll('circle')
  	.data(fruits, d => d.id);
  
  // Append New Elements to the Selection
  // (Data Elements that have no corresponding DOM Element)
  circles
    .enter().append('circle')
  		.attr('cx', xPosition)
      .attr('cy',height/2)
  		.attr('r',0)
  	// Use merge to Update Existing DOM Elements
  	.merge(circles)
      .attr('fill', d => colorScale(d.type))
  	.transition().duration(1000)
  		.attr('cx', xPosition)
      .attr('r', d => radiusScale(d.type));

  // Remove Leftover Elements from the Selection
  // ( DOM Elements that have not corresponding Data Element)
  circles
  	.exit()
    .transition().duration(1000)
      .attr('r', 0)
    .remove();
}